==> kubernetes-model-1.0.60-sources.jar: io/fabric8/kubernetes/api/model/EventSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class EventSourceBuilder extends EventSourceFluentImpl<EventSourceBuilder> implements VisitableBuilder<EventSource,EventSourceBuilder>{

    EventSourceFluent<?> fluent;
    Boolean validationEnabled;

    public EventSourceBuilder(){
            this(true);
    }
    public EventSourceBuilder(Boolean validationEnabled){
            this(new EventSource(), validationEnabled);
    }
    public EventSourceBuilder(EventSourceFluent<?> fluent){
            this(fluent, true);
    }
    public EventSourceBuilder(EventSourceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new EventSource(), validationEnabled);
    }
    public EventSourceBuilder(EventSourceFluent<?> fluent,EventSource instance){
            this(fluent, instance, true);
    }
    public EventSourceBuilder(EventSourceFluent<?> fluent,EventSource instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withComponent(instance.getComponent()); 
            fluent.withHost(instance.getHost()); 
            this.validationEnabled = validationEnabled; 
    }
    public EventSourceBuilder(EventSource instance){
            this(instance,true);
    }
    public EventSourceBuilder(EventSource instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withComponent(instance.getComponent()); 
            this.withHost(instance.getHost()); 
            this.validationEnabled = validationEnabled; 
    }

    public EventSource build(){
            EventSource buildable = new EventSource(fluent.getComponent(),fluent.getHost());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            EventSourceBuilder that = (EventSourceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.64-sources.jar: io/fabric8/kubernetes/api/model/EventSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class EventSourceBuilder extends EventSourceFluentImpl<EventSourceBuilder> implements VisitableBuilder<EventSource,EventSourceBuilder>{

    EventSourceFluent<?> fluent;
    Boolean validationEnabled;

    public EventSourceBuilder(){
            this(true);
    }
    public EventSourceBuilder(Boolean validationEnabled){
            this(new EventSource(), validationEnabled);
    }
    public EventSourceBuilder(EventSourceFluent<?> fluent){
            this(fluent, true);
    }
    public EventSourceBuilder(EventSourceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new EventSource(), validationEnabled);
    }
    public EventSourceBuilder(EventSourceFluent<?> fluent,EventSource instance){
            this(fluent, instance, true);
    }
    public EventSourceBuilder(EventSourceFluent<?> fluent,EventSource instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withComponent(instance.getComponent()); 
            fluent.withHost(instance.getHost()); 
            this.validationEnabled = validationEnabled; 
    }
    public EventSourceBuilder(EventSource instance){
            this(instance,true);
    }
    public EventSourceBuilder(EventSource instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withComponent(instance.getComponent()); 
            this.withHost(instance.getHost()); 
            this.validationEnabled = validationEnabled; 
    }

    public EventSource build(){
            EventSource buildable = new EventSource(fluent.getComponent(),fluent.getHost());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            EventSourceBuilder that = (EventSourceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
